@@ -83,7 +83,7 @@ int afs_dump(), afs_cmp(), afs_realvp(), afs_GetOnePage();
 int afs_pvn_vptrunc;
 
 int
-afs_addmap(register struct vnode *avp, offset_t offset, struct as *asp, 
+afs_addmap(struct vnode *avp, offset_t offset, struct as *asp, 
 	   caddr_t addr, int length, int prot, int maxprot, int flags, 
 	   afs_ucred_t *credp)
 {
@@ -92,7 +92,7 @@ afs_addmap(register struct vnode *avp, offset_t offset, struct as *asp,
 }
 
 int
-afs_delmap(register struct vnode *avp, offset_t offset, struct as *asp, 
+afs_delmap(struct vnode *avp, offset_t offset, struct as *asp, 
 	   caddr_t addr, int length, int prot, int maxprot, int flags, 
 	   afs_ucred_t *credp)
 {
@@ -102,15 +102,15 @@ afs_delmap(register struct vnode *avp, offset_t offset, struct as *asp,
 
 #ifdef AFS_SUN510_ENV
 int
-afs_vmread(register struct vnode *avp, struct uio *auio, int ioflag, 
+afs_vmread(struct vnode *avp, struct uio *auio, int ioflag, 
 	   afs_ucred_t *acred, caller_context_t *ct)
 #else
 int
-afs_vmread(register struct vnode *avp, struct uio *auio, int ioflag, 
+afs_vmread(struct vnode *avp, struct uio *auio, int ioflag, 
 	   afs_ucred_t *acred)
 #endif
 {
-    register int code;
+    int code;
 
     if (!RW_READ_HELD(&(VTOAFS(avp))->rwlock))
 	osi_Panic("afs_vmread: !rwlock");
@@ -123,15 +123,15 @@ afs_vmread(register struct vnode *avp, struct uio *auio, int ioflag,
 
 #ifdef AFS_SUN510_ENV
 int
-afs_vmwrite(register struct vnode *avp, struct uio *auio, int ioflag, 
+afs_vmwrite(struct vnode *avp, struct uio *auio, int ioflag, 
 	    afs_ucred_t *acred, caller_context_t *ct)
 #else
 int
-afs_vmwrite(register struct vnode *avp, struct uio *auio, int ioflag, 
+afs_vmwrite(struct vnode *avp, struct uio *auio, int ioflag, 
 	    afs_ucred_t *acred)
 #endif
 {
-    register int code;
+    int code;
 
     if (!RW_WRITE_HELD(&(VTOAFS(avp))->rwlock))
 	osi_Panic("afs_vmwrite: !rwlock");
@@ -146,7 +146,7 @@ afs_getpage(struct vnode *vp, offset_t off, u_int len, u_int *protp,
 	    struct page *pl[], u_int plsz, struct seg *seg, caddr_t addr, 
 	    enum seg_rw rw, afs_ucred_t *acred)
 {
-    register afs_int32 code = 0;
+    afs_int32 code = 0;
     AFS_STATCNT(afs_getpage);
 
     if (vp->v_flag & VNOMAP)	/* File doesn't allow mapping */
@@ -162,9 +162,34 @@ afs_getpage(struct vnode *vp, offset_t off, u_int len, u_int *protp,
 #endif
 			   off, len, protp, pl, plsz, seg, addr, rw, acred);
     else {
+	struct multiPage_range range;
 	struct vcache *vcp = VTOAFS(vp);
+
+	/* We've been asked to get more than one page. We must return all
+	 * requested pages at once, all of them locked, which means all of
+	 * these dcache entries cannot be kicked out of the cache before we
+	 * return (since their pages cannot be invalidated).
+	 *
+	 * afs_GetOnePage will be called multiple times by pvn_getpages in
+	 * order to get all of the requested pages. One of the later
+	 * afs_GetOnePage calls may need to evict some cache entries in order
+	 * to perform its read. If we try to kick out one of the entries an
+	 * earlier afs_GetOnePage call used, we will deadlock since we have
+	 * the page locked. So, to tell afs_GetDownD that it should skip over
+	 * any entries we've read in due to this afs_getpage call, record the
+	 * offset and length in avc->multiPage.
+	 *
+	 * Ideally we would just set something in each dcache as we get it,
+	 * but that is rather difficult, since pvn_getpages doesn't let us
+	 * retain any information between calls to afs_GetOnePage. So instead
+	 * just record the offset and length, and let afs_GetDownD calculate
+	 * which dcache entries should be skipped. */
+
+	range.off = off;
+	range.len = len;
+
 	ObtainWriteLock(&vcp->vlock, 548);
-	vcp->multiPage++;
+	QAdd(&vcp->multiPage, &range.q);
 	ReleaseWriteLock(&vcp->vlock);
 	afs_BozonLock(&vcp->pvnLock, vcp);
 	code =
@@ -175,7 +200,7 @@ afs_getpage(struct vnode *vp, offset_t off, u_int len, u_int *protp,
 			 off, len, protp, pl, plsz, seg, addr, rw, acred);
 	afs_BozonUnlock(&vcp->pvnLock, vcp);
 	ObtainWriteLock(&vcp->vlock, 549);
-	vcp->multiPage--;
+	QRemove(&range.q);
 	ReleaseWriteLock(&vcp->vlock);
     }
     AFS_GUNLOCK();
@@ -194,13 +219,13 @@ afs_GetOnePage(struct vnode *vp, u_int off, u_int alen, u_int *protp,
 	       enum seg_rw rw, afs_ucred_t *acred)
 #endif
 {
-    register struct page *page;
-    register afs_int32 code = 0;
+    struct page *page;
+    afs_int32 code = 0;
     u_int len;
     struct buf *buf;
     afs_int32 tlen;
-    register struct vcache *avc;
-    register struct dcache *tdc;
+    struct vcache *avc;
+    struct dcache *tdc;
     int i, s, pexists;
     int slot;
     afs_size_t offset, nlen = 0;
@@ -646,21 +671,21 @@ afs_putapage(struct vnode *vp, struct page *pages, u_int * offp,
 }
 
 int
-afs_nfsrdwr(register struct vcache *avc, struct uio *auio, enum uio_rw arw,
+afs_nfsrdwr(struct vcache *avc, struct uio *auio, enum uio_rw arw,
 	    int ioflag, afs_ucred_t *acred)
 {
-    register afs_int32 code;
+    afs_int32 code;
     afs_int32 code2;
     int counter;
     afs_int32 mode, sflags;
-    register char *data;
+    char *data;
     struct dcache *dcp, *dcp_newpage;
     afs_size_t fileBase, size;
     afs_size_t pageBase;
-    register afs_int32 tsize;
-    register afs_int32 pageOffset, extraResid = 0;
-    register afs_size_t origLength;	/* length when reading/writing started */
-    register long appendLength;	/* length when this call will finish */
+    afs_int32 tsize;
+    afs_int32 pageOffset, extraResid = 0;
+    afs_size_t origLength;	/* length when reading/writing started */
+    long appendLength;	/* length when this call will finish */
     int created;		/* created pages instead of faulting them */
     int lockCode;
     int didFakeOpen, eof;
@@ -1013,9 +1038,9 @@ int
 afs_map(struct vnode *vp, offset_t off, struct as *as, caddr_t *addr, u_int len, u_char prot, u_char maxprot, u_int flags, afs_ucred_t *cred)
 {
     struct segvn_crargs crargs;
-    register afs_int32 code;
+    afs_int32 code;
     struct vrequest treq;
-    register struct vcache *avc = VTOAFS(vp);
+    struct vcache *avc = VTOAFS(vp);
 
     AFS_STATCNT(afs_map);
 
@@ -1103,10 +1128,10 @@ afs_map(struct vnode *vp, offset_t off, struct as *as, caddr_t *addr, u_int len,
 int
 #ifdef AFS_SUN511_ENV
 afs_pathconf(struct vnode *vp, int cmd, u_long *outdatap,
-	     register afs_ucred_t *credp, caller_context_t *ct)
+	     afs_ucred_t *credp, caller_context_t *ct)
 #else
 afs_pathconf(struct vnode *vp, int cmd, u_long *outdatap,
-	     register afs_ucred_t *credp)
+	     afs_ucred_t *credp)
 #endif /* AFS_SUN511_ENV */
 {
     AFS_STATCNT(afs_cntl);
@@ -1168,7 +1193,7 @@ afs_rwunlock(struct vnode *vnp, int wlock)
 int
 afs_seek(struct vnode *vnp, offset_t ooff, offset_t *noffp)
 {
-    register int code = 0;
+    int code = 0;
 
 #ifndef AFS_64BIT_CLIENT
 # define __MAXOFF_T MAXOFF_T
@@ -1193,7 +1218,7 @@ afs_frlock(struct vnode *vnp, int cmd, struct flock *ap, int flag,
 	   offset_t off, afs_ucred_t *credp)
 #endif
 {
-    register afs_int32 code = 0;
+    afs_int32 code = 0;
     /*
      * Implement based on afs_lockctl
      */
@@ -1238,7 +1263,7 @@ afs_space(struct vnode *vnp, int cmd, struct flock *ap, int flag,
 	  offset_t off, afs_ucred_t *credp)
 #endif
 {
-    register afs_int32 code = EINVAL;
+    afs_int32 code = EINVAL;
     struct vattr vattr;
 
     if ((cmd == F_FREESP)
@@ -1345,60 +1370,60 @@ afs_getsecattr(struct vnode *vp, vsecattr_t *vsecattr, int flag, struct cred *cr
 #endif
 
 #ifdef	AFS_GLOBAL_SUNLOCK
-extern int gafs_open(register struct vcache **avcp, afs_int32 aflags, 
+extern int gafs_open(struct vcache **avcp, afs_int32 aflags, 
 		     afs_ucred_t *acred);
-extern int gafs_close(register struct vcache *avc, afs_int32 aflags, 
+extern int gafs_close(struct vcache *avc, afs_int32 aflags, 
 		      int count, offset_t offset, afs_ucred_t *acred);
 extern int afs_ioctl(struct vnode *vnp, int com, int arg, int flag, 
 		     cred_t *credp, int *rvalp);
-extern int gafs_access(register struct vcache *avc, register afs_int32 amode,
+extern int gafs_access(struct vcache *avc, afs_int32 amode,
 		       int flags, afs_ucred_t *acred);
-extern int gafs_getattr(register struct vcache *avc, 
-			register struct vattr *attrs, int flags, 
+extern int gafs_getattr(struct vcache *avc, 
+			struct vattr *attrs, int flags, 
 			afs_ucred_t *acred);
-extern int gafs_setattr(register struct vcache *avc, 
-			register struct vattr *attrs, int flags, 
+extern int gafs_setattr(struct vcache *avc, 
+			struct vattr *attrs, int flags, 
 			afs_ucred_t *acred);
-extern int gafs_lookup(register struct vcache *adp, char *aname, 
-		       register struct vcache **avcp, struct pathname *pnp,
+extern int gafs_lookup(struct vcache *adp, char *aname, 
+		       struct vcache **avcp, struct pathname *pnp,
 		       int flags, struct vnode *rdir, afs_ucred_t *acred);
-extern int gafs_remove(register struct vcache *adp, char *aname, 
+extern int gafs_remove(struct vcache *adp, char *aname, 
 		       afs_ucred_t *acred);
-extern int gafs_link(register struct vcache *adp, register struct vcache *avc,
+extern int gafs_link(struct vcache *adp, struct vcache *avc,
 		     char *aname, afs_ucred_t *acred);
-extern int gafs_rename(register struct vcache *aodp, char *aname1,
-		       register struct vcache *andp, char *aname2,
+extern int gafs_rename(struct vcache *aodp, char *aname1,
+		       struct vcache *andp, char *aname2,
 		       afs_ucred_t *acred);
-extern int gafs_symlink(register struct vcache *adp, char *aname, 
-			struct vattr *attrs, register char *atargetName, 
+extern int gafs_symlink(struct vcache *adp, char *aname, 
+			struct vattr *attrs, char *atargetName, 
 			afs_ucred_t *acred);
-extern int gafs_rmdir(register struct vcache *adp, char *aname, 
+extern int gafs_rmdir(struct vcache *adp, char *aname, 
 		      struct vnode *cdirp, afs_ucred_t *acred);
-extern int gafs_mkdir(register struct vcache *adp, char *aname, 
-		      struct vattr *attrs, register struct vcache **avcp, 
+extern int gafs_mkdir(struct vcache *adp, char *aname, 
+		      struct vattr *attrs, struct vcache **avcp, 
 		      afs_ucred_t *acred);
 extern int
 #ifdef  AFS_SUN53_ENV
-gafs_fsync(register struct vcache *avc, int flag, afs_ucred_t *acred);
+gafs_fsync(struct vcache *avc, int flag, afs_ucred_t *acred);
 #else
-gafs_fsync(register struct vcache *avc, afs_ucred_t *acred);
+gafs_fsync(struct vcache *avc, afs_ucred_t *acred);
 #endif
-extern int gafs_readlink(register struct vcache *avc, struct uio *auio, 
+extern int gafs_readlink(struct vcache *avc, struct uio *auio, 
 			 afs_ucred_t *acred);
-extern int gafs_readdir(register struct vcache *avc, struct uio *auio,
+extern int gafs_readdir(struct vcache *avc, struct uio *auio,
 			afs_ucred_t *acred, int *eofp);
-extern void gafs_inactive(register struct vcache *avc, 
+extern void gafs_inactive(struct vcache *avc, 
 			  afs_ucred_t *acred);
 extern int gafs_fid(struct vcache *avc, struct fid **fidpp);
-extern int gafs_create(register struct vcache *adp, char *aname, 
+extern int gafs_create(struct vcache *adp, char *aname, 
 		       struct vattr *attrs, enum vcexcl aexcl, int amode, 
 		       struct vcache **avcp, afs_ucred_t *acred);
 #ifdef AFS_SUN511_ENV
 extern int afs_pathconf(struct vnode *vp, int cmd, u_long *outdatap,
-			register afs_ucred_t *credp, caller_context_t *ct);
+			afs_ucred_t *credp, caller_context_t *ct);
 #else
 extern int afs_pathconf(struct vnode *vp, int cmd, u_long *outdatap,
-			register afs_ucred_t *credp);
+			afs_ucred_t *credp);
 #endif /* AFS_SUN511_ENV */
 
 #if defined(AFS_SUN511_ENV)
@@ -1553,10 +1578,10 @@ struct vnodeops *afs_ops = &Afs_vnodeops;
 #endif
 
 int
-gafs_open(register struct vcache **avcp, afs_int32 aflags, 
+gafs_open(struct vcache **avcp, afs_int32 aflags, 
 	  afs_ucred_t *acred)
 {
-    register int code;
+    int code;
 
     AFS_GLOCK();
     code = afs_open(avcp, aflags, acred);
@@ -1565,10 +1590,10 @@ gafs_open(register struct vcache **avcp, afs_int32 aflags,
 }
 
 int
-gafs_close(register struct vcache *avc, afs_int32 aflags, int count, 
+gafs_close(struct vcache *avc, afs_int32 aflags, int count, 
 	   offset_t offset, afs_ucred_t *acred)
 {
-    register int code;
+    int code;
 
     AFS_GLOCK();
     code = afs_close(avc, aflags, count, offset, acred);
@@ -1577,10 +1602,10 @@ gafs_close(register struct vcache *avc, afs_int32 aflags, int count,
 }
 
 int
-gafs_getattr(register struct vcache *avc, register struct vattr *attrs, 
+gafs_getattr(struct vcache *avc, struct vattr *attrs, 
 	     int flags, afs_ucred_t *acred)
 {
-    register int code;
+    int code;
 
     AFS_GLOCK();
     code = afs_getattr(avc, attrs, flags, acred);
@@ -1590,10 +1615,10 @@ gafs_getattr(register struct vcache *avc, register struct vattr *attrs,
 
 
 int
-gafs_setattr(register struct vcache *avc, register struct vattr *attrs, 
+gafs_setattr(struct vcache *avc, struct vattr *attrs, 
 	     int flags, afs_ucred_t *acred)
 {
-    register int code;
+    int code;
 
     AFS_GLOCK();
     code = afs_setattr(avc, attrs, flags, acred);
@@ -1603,10 +1628,10 @@ gafs_setattr(register struct vcache *avc, register struct vattr *attrs,
 
 
 int
-gafs_access(register struct vcache *avc, register afs_int32 amode, int flags, 
+gafs_access(struct vcache *avc, afs_int32 amode, int flags, 
 	    afs_ucred_t *acred)
 {
-    register int code;
+    int code;
 
     AFS_GLOCK();
     code = afs_access(avc, amode, flags, acred);
@@ -1616,11 +1641,11 @@ gafs_access(register struct vcache *avc, register afs_int32 amode, int flags,
 
 
 int
-gafs_lookup(register struct vcache *adp, char *aname, 
-	    register struct vcache **avcp, struct pathname *pnp, int flags, 
+gafs_lookup(struct vcache *adp, char *aname, 
+	    struct vcache **avcp, struct pathname *pnp, int flags, 
 	    struct vnode *rdir, afs_ucred_t *acred)
 {
-    register int code;
+    int code;
 
     AFS_GLOCK();
     code = afs_lookup(adp, aname, avcp, pnp, flags, rdir, acred);
@@ -1630,11 +1655,11 @@ gafs_lookup(register struct vcache *adp, char *aname,
 
 
 int
-gafs_create(register struct vcache *adp, char *aname, struct vattr *attrs, 
+gafs_create(struct vcache *adp, char *aname, struct vattr *attrs, 
 	    enum vcexcl aexcl, int amode, struct vcache **avcp, 
 	    afs_ucred_t *acred)
 {
-    register int code;
+    int code;
 
     AFS_GLOCK();
     code = afs_create(adp, aname, attrs, aexcl, amode, avcp, acred);
@@ -1643,9 +1668,9 @@ gafs_create(register struct vcache *adp, char *aname, struct vattr *attrs,
 }
 
 int
-gafs_remove(register struct vcache *adp, char *aname, afs_ucred_t *acred)
+gafs_remove(struct vcache *adp, char *aname, afs_ucred_t *acred)
 {
-    register int code;
+    int code;
 
     AFS_GLOCK();
     code = afs_remove(adp, aname, acred);
@@ -1654,10 +1679,10 @@ gafs_remove(register struct vcache *adp, char *aname, afs_ucred_t *acred)
 }
 
 int
-gafs_link(register struct vcache *adp, register struct vcache *avc, 
+gafs_link(struct vcache *adp, struct vcache *avc, 
 	  char *aname, afs_ucred_t *acred)
 {
-    register int code;
+    int code;
 
     AFS_GLOCK();
     code = afs_link(adp, avc, aname, acred);
@@ -1666,11 +1691,11 @@ gafs_link(register struct vcache *adp, register struct vcache *avc,
 }
 
 int
-gafs_rename(register struct vcache *aodp, char *aname1, 
-	    register struct vcache *andp, char *aname2, 
+gafs_rename(struct vcache *aodp, char *aname1, 
+	    struct vcache *andp, char *aname2, 
 	    afs_ucred_t *acred)
 {
-    register int code;
+    int code;
 
     AFS_GLOCK();
     code = afs_rename(aodp, aname1, andp, aname2, acred);
@@ -1681,7 +1706,10 @@ gafs_rename(register struct vcache *aodp, char *aname1,
 	(void) afs_lookup(andp, aname2, &avcp, NULL, 0, NULL, acred);
 	if (avcp) {
 	    struct vnode *vp = AFSTOV(avcp), *pvp = AFSTOV(andp);
-	    
+
+# ifdef HAVE_VN_RENAMEPATH
+	    vn_renamepath(pvp, vp, aname2, strlen(aname2));
+# else
 	    mutex_enter(&vp->v_lock);
 	    if (vp->v_path != NULL) {
 		kmem_free(vp->v_path, strlen(vp->v_path) + 1);
@@ -1689,6 +1717,7 @@ gafs_rename(register struct vcache *aodp, char *aname1,
 	    }
 	    mutex_exit(&vp->v_lock);
 	    vn_setpath(afs_globalVp, pvp, vp, aname2, strlen(aname2));
+# endif /* !HAVE_VN_RENAMEPATH */
 
 	    AFS_RELE(avcp);
 	}
@@ -1699,10 +1728,10 @@ gafs_rename(register struct vcache *aodp, char *aname1,
 }
 
 int
-gafs_mkdir(register struct vcache *adp, char *aname, struct vattr *attrs, 
-	   register struct vcache **avcp, afs_ucred_t *acred)
+gafs_mkdir(struct vcache *adp, char *aname, struct vattr *attrs, 
+	   struct vcache **avcp, afs_ucred_t *acred)
 {
-    register int code;
+    int code;
 
     AFS_GLOCK();
     code = afs_mkdir(adp, aname, attrs, avcp, acred);
@@ -1711,10 +1740,10 @@ gafs_mkdir(register struct vcache *adp, char *aname, struct vattr *attrs,
 }
 
 int
-gafs_rmdir(register struct vcache *adp, char *aname, struct vnode *cdirp, 
+gafs_rmdir(struct vcache *adp, char *aname, struct vnode *cdirp, 
 	   afs_ucred_t *acred)
 {
-    register int code;
+    int code;
 
     AFS_GLOCK();
     code = afs_rmdir(adp, aname, cdirp, acred);
@@ -1724,10 +1753,10 @@ gafs_rmdir(register struct vcache *adp, char *aname, struct vnode *cdirp,
 
 
 int
-gafs_readdir(register struct vcache *avc, struct uio *auio,
+gafs_readdir(struct vcache *avc, struct uio *auio,
 	     afs_ucred_t *acred, int *eofp)
 {
-    register int code;
+    int code;
 
     AFS_GLOCK();
     code = afs_readdir(avc, auio, acred, eofp);
@@ -1736,10 +1765,10 @@ gafs_readdir(register struct vcache *avc, struct uio *auio,
 }
 
 int
-gafs_symlink(register struct vcache *adp, char *aname, struct vattr *attrs,
-	     register char *atargetName, afs_ucred_t *acred)
+gafs_symlink(struct vcache *adp, char *aname, struct vattr *attrs,
+	     char *atargetName, afs_ucred_t *acred)
 {
-    register int code;
+    int code;
 
     AFS_GLOCK();
     code = afs_symlink(adp, aname, attrs, atargetName, acred);
@@ -1749,9 +1778,9 @@ gafs_symlink(register struct vcache *adp, char *aname, struct vattr *attrs,
 
 
 int
-gafs_readlink(register struct vcache *avc, struct uio *auio, afs_ucred_t *acred)
+gafs_readlink(struct vcache *avc, struct uio *auio, afs_ucred_t *acred)
 {
-    register int code;
+    int code;
 
     AFS_GLOCK();
     code = afs_readlink(avc, auio, acred);
@@ -1761,12 +1790,12 @@ gafs_readlink(register struct vcache *avc, struct uio *auio, afs_ucred_t *acred)
 
 int
 #ifdef	AFS_SUN53_ENV
-gafs_fsync(register struct vcache *avc, int flag, afs_ucred_t *acred)
+gafs_fsync(struct vcache *avc, int flag, afs_ucred_t *acred)
 #else
-gafs_fsync(register struct vcache *avc, afs_ucred_t *acred)
+gafs_fsync(struct vcache *avc, afs_ucred_t *acred)
 #endif
 {
-    register int code;
+    int code;
 
     AFS_GLOCK();
 #ifdef	AFS_SUN53_ENV
@@ -1803,6 +1832,7 @@ afs_inactive(struct vcache *avc, afs_ucred_t *acred)
     }
     mutex_exit(&vp->v_lock);
 
+#ifndef AFS_SUN511_ENV
     /*
      * Solaris calls VOP_OPEN on exec, but doesn't call VOP_CLOSE when
      * the executable exits.  So we clean up the open count here.
@@ -1813,13 +1843,23 @@ afs_inactive(struct vcache *avc, afs_ucred_t *acred)
      */
     if (avc->opens > 0 && avc->mvstat == 0 && !(avc->f.states & CCore))
 	avc->opens = avc->execsOrWriters = 0;
+#endif
 
     afs_InactiveVCache(avc, acred);
+
+#ifdef AFS_SUN58_ENV
+    AFS_GUNLOCK();
+    /* VFS_RELE must be called outside of GLOCK, since it can potentially
+     * call afs_freevfs, which acquires GLOCK */
+    VFS_RELE(afs_globalVFS);
+    AFS_GLOCK();
+#endif
+
     return 0;
 }
 
 void
-gafs_inactive(register struct vcache *avc, afs_ucred_t *acred)
+gafs_inactive(struct vcache *avc, afs_ucred_t *acred)
 {
     AFS_GLOCK();
     (void)afs_inactive(avc, acred);
@@ -1830,7 +1870,7 @@ gafs_inactive(register struct vcache *avc, afs_ucred_t *acred)
 int
 gafs_fid(struct vcache *avc, struct fid **fidpp)
 {
-    register int code;
+    int code;
 
     AFS_GLOCK();
     code = afs_fid(avc, fidpp);
