@@ -1,37 +1,37 @@
-/* 
+/*
  * $Id$
  *
  * Copyright 1990,1991 by the Massachusetts Institute of Technology
  * For distribution and copying rights, see the file "mit-copyright.h"
  */
 /*
- * Copyright (c) 2005, 2006                                     
- * The Linux Box Corporation                                    
- * ALL RIGHTS RESERVED                                          
- *                                                              
- * Permission is granted to use, copy, create derivative works  
- * and redistribute this software and such derivative works     
- * for any purpose, so long as the name of the Linux Box        
- * Corporation is not used in any advertising or publicity      
- * pertaining to the use or distribution of this software       
- * without specific, written prior authorization.  If the       
- * above copyright notice or any other identification of the    
- * Linux Box Corporation is included in any copy of any         
- * portion of this software, then the disclaimer below must     
- * also be included.                                            
- *                                                              
- * This software is provided as is, without representation      
- * from the Linux Box Corporation as to its fitness for any     
- * purpose, and without warranty by the Linux Box Corporation   
- * of any kind, either express or implied, including            
- * without limitation the implied warranties of                 
- * merchantability and fitness for a particular purpose.  The   
- * regents of the Linux Box Corporation shall not be liable     
- * for any damages, including special, indirect, incidental, or 
- * consequential damages, with respect to any claim arising     
- * out of or in connection with the use of the software, even   
- * if it has been or is hereafter advised of the possibility of 
- * such damages.                                                
+ * Copyright (c) 2005, 2006
+ * The Linux Box Corporation
+ * ALL RIGHTS RESERVED
+ *
+ * Permission is granted to use, copy, create derivative works
+ * and redistribute this software and such derivative works
+ * for any purpose, so long as the name of the Linux Box
+ * Corporation is not used in any advertising or publicity
+ * pertaining to the use or distribution of this software
+ * without specific, written prior authorization.  If the
+ * above copyright notice or any other identification of the
+ * Linux Box Corporation is included in any copy of any
+ * portion of this software, then the disclaimer below must
+ * also be included.
+ *
+ * This software is provided as is, without representation
+ * from the Linux Box Corporation as to its fitness for any
+ * purpose, and without warranty by the Linux Box Corporation
+ * of any kind, either express or implied, including
+ * without limitation the implied warranties of
+ * merchantability and fitness for a particular purpose.  The
+ * regents of the Linux Box Corporation shall not be liable
+ * for any damages, including special, indirect, incidental, or
+ * consequential damages, with respect to any claim arising
+ * out of or in connection with the use of the software, even
+ * if it has been or is hereafter advised of the possibility of
+ * such damages.
  */
 
 #include <afsconfig.h>
@@ -88,6 +88,7 @@
 #include <afs/venus.h>
 #include <afs/ptserver.h>
 #include <afs/ptuser.h>
+#include <afs/pterror.h>
 #include <afs/dirpath.h>
 #include <afs/afsutil.h>
 
@@ -187,7 +188,7 @@ static int get_user_realm(krb5_context, char **);
 #error "Must have either krb5_princ_size or krb5_principal_get_comp_string"
 #endif
 
-#if !defined(HAVE_KRB5_ENCRYPT_TKT_PART) && defined(HAVE_ENCODE_KRB5_ENC_TKT_PART) && defined(HAVE_KRB5_C_ENCRYPT) 
+#if !defined(HAVE_KRB5_ENCRYPT_TKT_PART) && defined(HAVE_ENCODE_KRB5_ENC_TKT_PART) && defined(HAVE_KRB5_C_ENCRYPT)
 extern krb5_error_code encode_krb5_enc_tkt_part (const krb5_enc_tkt_part *rep,
 						 krb5_data **code);
 
@@ -199,7 +200,7 @@ krb5_encrypt_tkt_part(krb5_context context,
     krb5_data *data = 0;
     int code;
     size_t enclen;
-    
+
     if ((code = encode_krb5_enc_tkt_part(ticket->enc_part2, &data)))
 	goto Done;
     if ((code = krb5_c_encrypt_length(context, key->enctype,
@@ -241,10 +242,11 @@ Done:
 #error "Must have either keyblock or session member of krb5_creds"
 #endif
 
-#if !defined(HAVE_KRB5_524_CONVERT_CREDS) && defined(HAVE_KRB524_CONVERT_CREDS_KDC)
-#define krb5_524_convert_creds krb524_convert_creds_kdc
-#elif !defined(HAVE_KRB5_524_CONVERT_CREDS) && !defined(HAVE_KRB524_CONVERT_CREDS_KDC)
+/* MITKerberosShim logs but returns success */
+#if !defined(HAVE_KRB5_524_CONV_PRINCIPAL) || defined(AFS_DARWIN110_ENV) || (!defined(HAVE_KRB5_524_CONVERT_CREDS) && !defined(HAVE_KRB524_CONVERT_CREDS_KDC))
 #define HAVE_NO_KRB5_524
+#elif !defined(HAVE_KRB5_524_CONVERT_CREDS) && defined(HAVE_KRB524_CONVERT_CREDS_KDC)
+#define krb5_524_convert_creds krb524_convert_creds_kdc
 #endif
 
 #if USING_HEIMDAL
@@ -334,8 +336,10 @@ redirect_errors(const char *who, afs_int32 code, const char *fmt, va_list ap)
 	if (strncmp(str, "unknown", strlen("unknown")) == 0) {
 #ifdef HAVE_KRB5_SVC_GET_MSG
 	    krb5_svc_get_msg(code,&str);
-#else
+#elif defined(HAVE_ERROR_MESSAGE)
 	    str = error_message(code);
+#else
+	    ; /* IRIX apparently has neither: use the string we have */
 #endif
 	}
 	fputs(str, stderr);
@@ -368,7 +372,7 @@ copy_cellinfo(cellinfo_t *cellinfo)
 
     if ((new_cellinfo = (cellinfo_t *)malloc(sizeof(cellinfo_t))))
 	memcpy(new_cellinfo, cellinfo, sizeof(cellinfo_t));
-    
+
     return ((char *)new_cellinfo);
 }
 
@@ -389,7 +393,7 @@ get_cellconfig(char *cell, struct afsconf_cell *cellconfig, char **local_cell)
     }
 
     if (!(configdir = afsconf_Open(AFSDIR_CLIENT_ETC_DIRPATH))) {
-	fprintf(stderr, 
+	fprintf(stderr,
 		"%s: can't get afs configuration (afsconf_Open(%s))\n",
 		progname, AFSDIR_CLIENT_ETC_DIRPATH);
 	exit(AKLOG_AFS);
@@ -616,6 +620,11 @@ rxkad_get_ticket(krb5_context context, char *realm,
 	fprintf(stderr, "%s: Couldn't get %s AFS tickets:\n",
 		progname, cell->name);
 	afs_com_err(progname, status, "while getting AFS tickets");
+#ifdef KRB5_CC_NOT_KTYPE
+	if (status == KRB5_CC_NOT_KTYPE) {
+	    fprintf(stderr, "allow_weak_crypto may be required in the Kerberos configuration\n");
+	}
+#endif
 	status = AKLOG_KERBEROS;
 	goto out;
     }
@@ -671,15 +680,16 @@ out:
 static int
 rxkad_build_native_token(krb5_context context, krb5_creds *v5cred,
 			 struct ktc_token **tokenPtr, char **userPtr) {
-    char k4name[ANAME_SZ];
-    char k4inst[INST_SZ];
-    char k4realm[REALM_SZ];
     char username[BUFSIZ];
     struct ktc_token *token;
-    int status;
 #ifdef HAVE_NO_KRB5_524
     char *p;
     int len;
+#else
+    int status;
+    char k4name[ANAME_SZ];
+    char k4inst[INST_SZ];
+    char k4realm[REALM_SZ];
 #endif
 
     afs_dprintf("Using Kerberos V5 ticket natively\n");
@@ -815,6 +825,9 @@ rxkad_get_converted_token(krb5_context context, krb5_creds *v5cred,
     token->ticketLen = cred.ticket_st.length;
     memcpy(token->ticket, cred.ticket_st.dat, token->ticketLen);
 
+    *tokenPtr = token;
+    *userPtr = strdup(username);
+
     return 0;
 }
 #endif
@@ -944,7 +957,7 @@ tokens_equal(struct ktc_token *tokenA, struct ktc_token *tokenB) {
 	    !memcmp(tokenA->ticket, tokenB->ticket, tokenA->ticketLen));
 }
 
-/* 
+/*
  * Log to a cell.  If the cell has already been logged to, return without
  * doing anything.  Otherwise, log to it and mark that it has been logged
  * to.
@@ -966,11 +979,15 @@ auth_to_cell(krb5_context context, char *cell, char *realm, char **linkedcell)
     if ((status = get_cellconfig(cell, &cellconf, &local_cell)))
 	return(status);
 
-    if (linkedcell != NULL && cellconf.linkedCell != NULL) {
-	*linkedcell = strdup(cellconf.linkedCell);
-	if (*linkedcell == NULL) {
-	    status = ENOMEM;
-	    goto out;
+    if (linkedcell != NULL) {
+	if (cellconf.linkedCell != NULL) {
+	    *linkedcell = strdup(cellconf.linkedCell);
+	    if (*linkedcell == NULL) {
+		status = ENOMEM;
+		goto out;
+	    }
+	} else {
+	    *linkedcell = NULL;
 	}
     }
 
@@ -980,14 +997,14 @@ auth_to_cell(krb5_context context, char *cell, char *realm, char **linkedcell)
 	goto out;
     }
 
-    /* 
+    /*
      * Record that we have attempted to log to this cell.  We do this
      * before we try rather than after so that we will not try
      * and fail repeatedly for one cell.
      */
     ll_string(&authedcells, ll_s_add, cellconf.name);
 
-    /* 
+    /*
      * Record this cell in the list of zephyr subscriptions.  We may
      * want zephyr subscriptions even if authentication fails.
      * If this is done after we attempt to get tokens, aklog -zsubs
@@ -995,13 +1012,13 @@ auth_to_cell(krb5_context context, char *cell, char *realm, char **linkedcell)
      * are in -noauth mode.
      */
     if (ll_string(&zsublist, ll_s_add, cellconf.name) == LL_FAILURE) {
-	fprintf(stderr, 
+	fprintf(stderr,
 		"%s: failure adding cell %s to zephyr subscriptions list.\n",
 		progname, cellconf.name);
 	exit(AKLOG_MISC);
     }
     if (ll_string(&zsublist, ll_s_add, local_cell) == LL_FAILURE) {
-	fprintf(stderr, 
+	fprintf(stderr,
 		"%s: failure adding cell %s to zephyr subscriptions list.\n",
 		progname, local_cell);
 	exit(AKLOG_MISC);
@@ -1043,7 +1060,7 @@ auth_to_cell(krb5_context context, char *cell, char *realm, char **linkedcell)
 		afs_dprintf("Error %d\n", status);
 	    else
 		afs_dprintf("Id %d\n", (int) viceId);
-	    
+
 
 	    /*
 	     * This code is taken from cklog -- it lets people
@@ -1099,7 +1116,12 @@ auth_to_cell(krb5_context context, char *cell, char *realm, char **linkedcell)
 	     */
 
 	    if ((status == 0) && (viceId != ANONYMOUSID)) {
-		sprintf(username, "AFS ID %d", (int) viceId);
+		free(username);
+		if (afs_asprintf(&username, "AFS ID %d", (int) viceId) < 0) {
+		    status = ENOMEM;
+		    username = NULL;
+		    goto out;
+		}
 	    }
 	}
 
@@ -1109,7 +1131,7 @@ auth_to_cell(krb5_context context, char *cell, char *realm, char **linkedcell)
 
 #ifndef AFS_AIX51_ENV
 	/* on AIX 4.1.4 with AFS 3.4a+ if a write is not done before
-	 * this routine, it will not add the token. It is not clear what 
+	 * this routine, it will not add the token. It is not clear what
 	 * is going on here! So we will do the following operation.
 	 * On AIX 5, it causes the parent program to die, so we won't.
 	 */
@@ -1156,8 +1178,8 @@ get_afs_mountpoint(char *file, char *mountpoint, int size)
     else {
 	last_component = our_file;
 	parent_dir = ".";
-    }    
-    
+    }
+
     memset(cellname, 0, sizeof(cellname));
 
     vio.in = last_component;
@@ -1171,7 +1193,7 @@ get_afs_mountpoint(char *file, char *mountpoint, int size)
 	    vio.in_size = strlen(file) + 1;
 	    vio.out_size = sizeof(cellname);
 	    vio.out = cellname;
-	    
+
 	    if (!pioctl(file, VIOC_FILE_CELL_NAME, &vio, 1)) {
 		strcat(cellname, VOLMARKERSTRING);
 		strcat(cellname, mountpoint + 1);
@@ -1185,8 +1207,8 @@ get_afs_mountpoint(char *file, char *mountpoint, int size)
 	return(FALSE);
 }
 
-/* 
- * This routine each time it is called returns the next directory 
+/*
+ * This routine each time it is called returns the next directory
  * down a pathname.  It resolves all symbolic links.  The first time
  * it is called, it should be called with the name of the path
  * to be descended.  After that, it should be called with the arguemnt
@@ -1206,9 +1228,9 @@ next_path(char *origpath)
     static char *elast_comp;	/* End of last component */
     char *t;
     int len;
-    
+
     static int symlinkcount = 0; /* We can't exceed MAXSYMLINKS */
-    
+
     /* If we are given something for origpath, we are initializing only. */
     if (origpath) {
 	memset(path, 0, sizeof(path));
@@ -1220,7 +1242,7 @@ next_path(char *origpath)
     }
 
     /* We were not given origpath; find then next path to check */
-    
+
     /* If we've gotten all the way through already, return NULL */
     if (last_comp == NULL)
 	return(NULL);
@@ -1228,11 +1250,11 @@ next_path(char *origpath)
     do {
 	while (*last_comp == DIR)
 	    strncat(pathtocheck, last_comp++, 1);
-	len = (elast_comp = strchr(last_comp, DIR)) 
+	len = (elast_comp = strchr(last_comp, DIR))
 	    ? elast_comp - last_comp : strlen(last_comp);
 	strncat(pathtocheck, last_comp, len);
 	memset(linkbuf, 0, sizeof(linkbuf));
-	if ((link = (readlink(pathtocheck, linkbuf, 
+	if ((link = (readlink(pathtocheck, linkbuf,
 				    sizeof(linkbuf)) > 0))) {
 	    if (++symlinkcount > MAXSYMLINKS) {
 		fprintf(stderr, "%s: %s\n", progname, strerror(ELOOP));
@@ -1242,8 +1264,8 @@ next_path(char *origpath)
 	    if (elast_comp)
 		strcpy(tmpbuf, elast_comp);
 	    if (linkbuf[0] == DIR) {
-		/* 
-		 * If this is a symbolic link to an absolute path, 
+		/*
+		 * If this is a symbolic link to an absolute path,
 		 * replace what we have by the absolute path.
 		 */
 		memset(path, 0, strlen(path));
@@ -1254,8 +1276,8 @@ next_path(char *origpath)
 		memset(pathtocheck, 0, sizeof(pathtocheck));
 	    }
 	    else {
-		/* 
-		 * If this is a symbolic link to a relative path, 
+		/*
+		 * If this is a symbolic link to a relative path,
 		 * replace only the last component with the link name.
 		 */
 		strncpy(last_comp, linkbuf, strlen(linkbuf) + 1);
@@ -1289,7 +1311,7 @@ add_hosts(char *file)
     int i;
     struct hostent *hp;
     struct in_addr in;
-    
+
     memset(outbuf, 0, sizeof(outbuf));
 
     vio.out_size = sizeof(outbuf);
@@ -1311,7 +1333,7 @@ add_hosts(char *file)
 	 * If it is replicated on many servers, then none are included.
 	 * This is not perfect, but the result is that people don't
 	 * get subscribed to a lot of instances of FILSRV that they
-	 * probably won't need which reduces the instances of 
+	 * probably won't need which reduces the instances of
 	 * people getting messages that don't apply to them.
 	 */
 #ifndef ALLHOSTS
@@ -1333,7 +1355,7 @@ add_hosts(char *file)
 }
 
 /*
- * This routine descends through a path to a directory, logging to 
+ * This routine descends through a path to a directory, logging to
  * every cell it encounters along the way.
  */
 static int
@@ -1372,9 +1394,9 @@ auth_to_path(krb5_context context, char *path)
     while ((nextpath = next_path(NULL))) {
 	strcpy(pathtocheck, nextpath);
 	afs_dprintf("Checking directory %s\n", pathtocheck);
-	/* 
-	 * If this is an afs mountpoint, determine what cell from 
-	 * the mountpoint name which is of the form 
+	/*
+	 * If this is an afs mountpoint, determine what cell from
+	 * the mountpoint name which is of the form
 	 * #cellname:volumename or %cellname:volumename.
 	 */
 	if (get_afs_mountpoint(pathtocheck, mountpoint, sizeof(mountpoint))) {
@@ -1399,9 +1421,9 @@ auth_to_path(krb5_context context, char *path)
 	    if (isdir(pathtocheck, &isdirectory) < 0) {
 		/*
 		 * If we've logged and still can't stat, there's
-		 * a problem... 
+		 * a problem...
 		 */
-		fprintf(stderr, "%s: stat(%s): %s\n", progname, 
+		fprintf(stderr, "%s: stat(%s): %s\n", progname,
 			pathtocheck, strerror(errno));
 		return(AKLOG_BADPATH);
 	    }
@@ -1413,7 +1435,7 @@ auth_to_path(krb5_context context, char *path)
 	    }
 	}
     }
-    
+
 
     return(status);
 }
@@ -1494,8 +1516,42 @@ main(int argc, char *argv[])
     else
 	progname = argv[0];
 
-    krb5_init_context(&context);
-    initialize_ktc_error_table ();
+#if defined(KRB5_PROG_ETYPE_NOSUPP) && !(defined(HAVE_KRB5_ENCTYPE_ENABLE) || defined(HAVE_KRB5_ALLOW_WEAK_CRYPTO))
+    {
+	char *filepath = NULL, *newpath = NULL;
+#ifndef AFS_DARWIN_ENV
+	char *defaultpath = "/etc/krb5.conf:/etc/krb5/krb5.conf";
+#else
+	char *defaultpath = "~/Library/Preferences/edu.mit.Kerberos:/Library/Preferences/edu.mit.Kerberos";
+#endif
+	filepath = getenv("KRB5_CONFIG");
+
+	/* only fiddle with KRB5_CONFIG if krb5-weak.conf actually exists */
+	afs_asprintf(&newpath, "%s/krb5-weak.conf", AFSDIR_CLIENT_ETC_DIRPATH);
+	if (access(newpath, R_OK) == 0) {
+	    free(newpath);
+	    newpath = NULL;
+	    afs_asprintf(&newpath, "%s:%s/krb5-weak.conf",
+	                 filepath ? filepath : defaultpath,
+	                 AFSDIR_CLIENT_ETC_DIRPATH);
+	    setenv("KRB5_CONFIG", newpath, 1);
+	}
+#endif
+	krb5_init_context(&context);
+
+#if defined(KRB5_PROG_ETYPE_NOSUPP) && !(defined(HAVE_KRB5_ENCTYPE_ENABLE) || defined(HAVE_KRB5_ALLOW_WEAK_CRYPTO))
+	free(newpath);
+	if (filepath)
+	    setenv("KRB5_CONFIG", filepath, 1);
+	else
+	    unsetenv("KRB5_CONFIG");
+    }
+#endif
+    initialize_KTC_error_table ();
+    initialize_U_error_table();
+    initialize_RXK_error_table();
+    initialize_ACFG_error_table();
+    initialize_PT_error_table();
     afs_set_com_err_hook(redirect_errors);
 
     /*
@@ -1503,12 +1559,12 @@ main(int argc, char *argv[])
      * krb5_allow_weak_crypto is MIT Kerberos 1.8.  krb5_enctype_enable is
      * Heimdal.
      */
-#if defined(HAVE_KRB5_ALLOW_WEAK_CRYPTO)
-    krb5_allow_weak_crypto(context, 1);
-#elif defined(HAVE_KRB5_ENCTYPE_ENABLE)
+#if defined(HAVE_KRB5_ENCTYPE_ENABLE)
     i = krb5_enctype_valid(context, ETYPE_DES_CBC_CRC);
     if (i)
         krb5_enctype_enable(context, ETYPE_DES_CBC_CRC);
+#elif defined(HAVE_KRB5_ALLOW_WEAK_CRYPTO)
+    krb5_allow_weak_crypto(context, 1);
 #endif
 
     /* Initialize list of cells to which we have authenticated */
@@ -1518,7 +1574,7 @@ main(int argc, char *argv[])
     for (i = 1; i < argc; i++) {
 	if (strcmp(argv[i], "-d") == 0)
 	    dflag++;
-	else if (strcmp(argv[i], "-noauth") == 0) 
+	else if (strcmp(argv[i], "-noauth") == 0)
 	    noauth++;
 	else if (strcmp(argv[i], "-zsubs") == 0)
 	    zsubs++;
@@ -1564,7 +1620,7 @@ main(int argc, char *argv[])
 	    }
 	    else
 		usage();
-	    
+
 	else if (argv[i][0] == '-')
 	    usage();
 	else if (!pmode && !cmode) {
@@ -1573,7 +1629,7 @@ main(int argc, char *argv[])
 		pmode++;
 		strcpy(path, argv[i]);
 	    }
-	    else { 
+	    else {
 		cmode++;
 		strcpy(cell, argv[i]);
 	    }
@@ -1597,7 +1653,7 @@ main(int argc, char *argv[])
 		if ((new_cellinfo = copy_cellinfo(&cellinfo)))
 		    ll_add_data(cur_node, new_cellinfo);
 		else {
-		    fprintf(stderr, 
+		    fprintf(stderr,
 			    "%s: failure copying cellinfo.\n", progname);
 		    exit(AKLOG_MISC);
 		}
@@ -1639,7 +1695,7 @@ main(int argc, char *argv[])
 	struct passwd *pwd;
 
 	status = auth_to_cell(context, NULL, NULL, &linkedcell);
-	
+
 	/* If this cell is linked to a DCE cell, and user requested -linked,
 	 * get tokens for both. This is very useful when the AFS cell is
 	 * linked to a DFS cell and this system does not also have DFS.
@@ -1716,9 +1772,9 @@ main(int argc, char *argv[])
 	    if ((status = auth_to_path(context, cur_node->data)))
 		somethingswrong++;
 	}
-	
-	/* 
-	 * If only one thing was logged to, we'll return the status 
+
+	/*
+	 * If only one thing was logged to, we'll return the status
 	 * of the single call.  Otherwise, we'll return a generic
 	 * something failed status.
 	 */
@@ -1727,7 +1783,7 @@ main(int argc, char *argv[])
     }
 
     /* If we are keeping track of zephyr subscriptions, print them. */
-    if (zsubs) 
+    if (zsubs)
 	for (cur_node = zsublist.first; cur_node; cur_node = cur_node->next) {
 	    printf("zsub: %s\n", cur_node->data);
 	}
@@ -1749,12 +1805,12 @@ isdir(char *path, unsigned char *val)
     if (lstat(path, &statbuf) < 0)
 	return (-1);
     else {
-	if ((statbuf.st_mode & S_IFMT) == S_IFDIR) 
+	if ((statbuf.st_mode & S_IFMT) == S_IFDIR)
 	    *val = TRUE;
 	else
 	    *val = FALSE;
 	return (0);
-    }  
+    }
 }
 
 static krb5_error_code
@@ -1789,8 +1845,8 @@ get_credv5_akimpersonate(krb5_context context,
     krb5_ticket ticket_reply[1];
     krb5_enc_tkt_part enc_tkt_reply[1];
     krb5_address address[30], *faddr[30];
-#endif
     krb5_data * temp;
+#endif
     int i;
     static int any_enctype[] = {0};
     *out_creds = 0;
@@ -1913,7 +1969,7 @@ get_credv5_akimpersonate(krb5_context context,
     enc_tkt_reply->times.starttime = starttime; /* krb524init needs this */
     enc_tkt_reply->times.endtime = endtime;
 #endif  /* USING_HEIMDAL */
-    /* NB:  We will discard address for now--ignoring caddr field               
+    /* NB:  We will discard address for now--ignoring caddr field
        in any case.  MIT branch does what it always did. */
 
     if (paddress && *paddress) {
@@ -1965,8 +2021,8 @@ get_credv5_akimpersonate(krb5_context context,
 
         if(buf_len != buf_size) {
             afs_com_err(progname, code,
-		    "%d != %d while encoding ticket (internal ASN.1 encoder error",
-		    buf_len, buf_size);
+		    "%u != %u while encoding ticket (internal ASN.1 encoder error",
+		    (unsigned int)buf_len, (unsigned int)buf_size);
             goto cleanup;
         }
         what = "krb5_crypto_init";
@@ -2071,7 +2127,6 @@ cleanup:
         krb5_kt_close(context, kt);
     if (creds) krb5_free_creds(context, creds);
     krb5_free_keyblock_contents(context, session_key);
-out:
     return code;
 #else
     return -1;
@@ -2089,7 +2144,7 @@ get_credv5(krb5_context context, char *name, char *inst, char *realm,
 
     afs_dprintf("Getting tickets: %s%s%s@%s\n", name,
 	    (inst && inst[0]) ? "/" : "", inst ? inst : "", realm);
-    
+
     memset(&increds, 0, sizeof(increds));
 /* ANL - instance may be ptr to a null string. Pass null then */
     if ((r = krb5_build_principal(context, &increds.server,
@@ -2099,7 +2154,7 @@ get_credv5(krb5_context context, char *name, char *inst, char *realm,
 				  (void *) NULL))) {
         return r;
     }
-    
+
 
     if (!_krb425_ccache) {
         r = krb5_cc_default(context, &_krb425_ccache);
@@ -2115,12 +2170,12 @@ get_credv5(krb5_context context, char *name, char *inst, char *realm,
 	if (r)
 	    return r;
     }
-    
+
     increds.client = client_principal;
     increds.times.endtime = 0;
     /* Ask for DES since that is what V4 understands */
     get_creds_enctype((&increds)) = ENCTYPE_DES_CBC_CRC;
-    
+
     if (keytab) {
 	int allowed_enctypes[] = {
 	    ENCTYPE_DES_CBC_CRC, 0
@@ -2136,7 +2191,7 @@ get_credv5(krb5_context context, char *name, char *inst, char *realm,
 				     creds /* out */);
     } else {
 	r = krb5_get_credentials(context, 0, _krb425_ccache, &increds, creds);
-    }    
+    }
     return r;
 }
 
@@ -2149,8 +2204,11 @@ get_user_realm(krb5_context context, char **realm)
 
     *realm = NULL;
 
-    if (!_krb425_ccache)
-        krb5_cc_default(context, &_krb425_ccache);
+    if (!_krb425_ccache) {
+	r = krb5_cc_default(context, &_krb425_ccache);
+	if (r)
+	    return r;
+    }
     if (!client_principal) {
 	if (client) {
 	    r = krb5_parse_name(context, client,  &client_principal);
